pub struct DecoderOutput { /* private fields */ }Expand description
Instance of this type is used to receive decoded pictures.
Implementations
Sourceimpl DecoderOutput
impl DecoderOutput
Sourcepub fn next_picture(&mut self) -> Option<Image<'_>>
pub fn next_picture(&mut self) -> Option<Image<'_>>
Return the next decoded picture if there is any.